<template>
  <div class="container">
    <h1 class="fs-3 fl-4">Delete Account</h1>

    <p class="fl-5">
      <p>To delete your account, check your credit balance. If credit is remain, you should spend all credits.</p>

      <p class="fs-5 my-8">
        Your Credit Balance: <span class="fw-bold">{{ credit_balance.format () }}</span>
      </p>

      <p v-if="credit_balance == 0">You must provide your current password in order to delete account.
        <form class="bg-grey-lighten-3 rounded-2 px-4 py-2 mt-2 mb-7 col-md-9 col-lg-7 col-xxl-6">
          <bs-input name="password" v-model="password" label="Password" type="password" placeholder="Enter your current password"></bs-input>
        </form>

        <div class="col-md-9 col-lg-7 col-xxl-6 mt-8">
          <p>Are you sure to delete account? This action <b>cannot be undone</b>.</p>
        </div>
      </p>
      <p v-else class="text-red-darken-1">Cannot delete account because your credit is remain.</p>

      <div class="mt-4 actions">
        <button class="mr-4 btn btn-danger" type="button" @click="resign" :disabled="state.$waiting || credit_balance > 0">
          <span v-if="state.$waiting" class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Yes, Delete Account</button>
        <button class="btn btn-secondary" type="button" @click="cancel">Cancel</button>
      </div>

    </p>
  </div>
</template>

<script setup>
import BsInput from "/atila-vue/components/bs-input.vue"

const { state } = useStore ()
const password = ref ('')
const credit_balance = ref (0)

function cancel () {
  router.back ()
}

onMounted (async () => {
  const resp = await backend.get ('CREDITS')
  credit_balance.value = resp.data.balance
  // credit_balance.value = 0
})

async function resign () {
  const validators = {password: {required: true, len__between: [6, 64]}}
  if (frontend.validator.failed ({password: password.value}, validators)) {
    return
  }

  state.$waiting = true
  try {
    const auth = await firebase.getAuth ()
    const userCredential = await firebase.auth.signInWithEmailAndPassword (auth, state.$claims.email, password.value)
    await firebase.auth.deleteUser (userCredential.user)
  } catch (error) {
    return frontend.handle_firebase_error (error, "Delete Account")
  }
  const r = await backend.remove_access_and_refresh_tokens ("ATILA_VUE_AUTH_DELETE_USER")

  if (r.error) {
    return bootstrap.modal ({
      title: "Unable To Delete Account",
      text: 'Unknown error occured. Please contact us.',
      icon: "error",
      closeButtonText: 'Retry'
    })
  }

  bootstrap.toast ({title: "Good Bye", text: "Your account has been successfully deleted."})
  router.push ("/")
}

onActivated (() => {
  frontend.set_title ()
})

</script>

<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.required (['user'], {path: '/members/signin'}, {to, from, next})
  }
}
</script>